@@ -3,7 +3,7 @@ use crate::ctx;
 
 use anyhow::{anyhow, Result};
 use dirs::home_dir;
-use skim::prelude::{unbounded, SkimOptionsBuilder};
+use skim::prelude::{unbounded, Key, SkimOptionsBuilder};
 use skim::{Skim, SkimItemReceiver, SkimItemSender};
 use std::path::PathBuf;
 use std::sync::Arc;
@@ -39,7 +39,7 @@ impl ctx::CTX for AWS {
     fn use_context(&self, name: &str) -> Result<ctx::Context, ctx::CTXError> {
         let mut creds = Credentials::load_credentials(&self.credentials_path)?;
         let profile = creds.set_default_profile(name)?;
-        creds.dump_credential(&self.credentials_path)?;
+        creds.dump_credentials(&self.credentials_path)?;
         Ok(ctx::Context {
             name: profile.name,
             active: profile.default,
@@ -54,10 +54,8 @@ impl ctx::CTX for AWS {
             .height(Some("30%"))
             .multi(false)
             .build()
-            .or_else(|err| {
-                Err(ctx::CTXError::UnexpectedError {
-                    source: anyhow!(err),
-                })
+            .map_err(|err| ctx::CTXError::UnexpectedError {
+                source: anyhow!(err),
             })?;
 
         let (tx_item, rx_item): (SkimItemSender, SkimItemReceiver) = unbounded();
@@ -67,13 +65,14 @@ impl ctx::CTX for AWS {
         drop(tx_item);
 
         let selected_items = Skim::run_with(&options, Some(rx_item))
-            .map(|out| out.selected_items)
-            .unwrap_or_else(Vec::new);
+            .map(|out| match out.final_key {
+                Key::Enter => Ok(out.selected_items),
+                _ => Err(ctx::CTXError::NoContextIsSelected {}),
+            })
+            .unwrap_or(Ok(Vec::new()))?;
         let item = selected_items
             .get(0)
-            .ok_or(ctx::CTXError::InvalidArgument {
-                source: anyhow!("no context is selected"),
-            })?;
+            .ok_or(ctx::CTXError::NoContextIsSelected {})?;
         let context = (*item)
             .as_any()
             .downcast_ref::<ctx::Context>()
